==> nestor_qt-0.3.2-py3-none-any.whl: README.md <==
#`nestor-qt`
Legacy user-interface to the [nestor](github.com/usnistgov/nestor) workflow.

## Purpose

This interface was designed to help manufacturers "tag" their
maintenance work-order data using the `nestor` workflow. 
It takes advantage of keyword prioritization and relationship/link prediction to assist in dataset labeling *without* having to look at the data document-by-document. 

The current build is an alpha tool built for reasearch purposes, so please be patient while using it. 
See the [main nestor page](github.com/usnistgov/nestor) for more information. 
Ifyou have any questions, please do not hesitate to contact us (see [Who
are we?](#who-are-we). )

## Installation

``` bash
pip install nestor-qt
```

> Past releases have provided executable files, which are still available. 
> New executables are in-development, via beeware's `briefcase` framework.

Requirments: `python>=3.7`. 
Use of virtual environment (pyenv, pipenv, conda, etc.) is recommended.  

With a python installation 

## Who are we?

This toolkit is a part of the Knowledge Extraction and Application for
Smart Manufacturing (KEA) project, within the Systems Integration
Division at NIST.

### Points of Contact

-   [Thurston Sexton](https://www.nist.gov/people/thurston-sexton) Nestor Technical Lead
-   [Michael Brundage](https://www.nist.gov/people/michael-p-brundage)
    Principal Investigator

### Contributors to `nestor-qt`:

Name             |   GitHub Handle
---              |   ---
Thurston Sexton  |   [@tbsexton](https://github.com/tbsexton)
Sascha Moccozet  |   [@saschaMoccozet](https://github.com/saschaMoccozet)
Michael Brundage |   [@MichaelPBrundage](https://github.com/MichaelPBrundage)
Madhusudanan N.  |   [@msngit](https://github.com/msngit)
Emily Hastings   |   [@emhastings](https://github.com/emhastings)
Lela Bones       |   [@lelatbones](https://github.com/lelatbones)

==> nestor_qt-0.3.5-py3-none-any.whl: README.md <==
#`nestor-qt`
Legacy user-interface to the [nestor](github.com/usnistgov/nestor) workflow.

## Purpose

This interface was designed to help manufacturers "tag" their
maintenance work-order data using the `nestor` workflow. 
It takes advantage of keyword prioritization and relationship/link prediction to assist in dataset labeling *without* having to look at the data document-by-document. 

The current build is an alpha tool built for reasearch purposes, so please be patient while using it. 
See the [main nestor page](github.com/usnistgov/nestor) for more information. 
Ifyou have any questions, please do not hesitate to contact us (see [Who
are we?](#who-are-we). )

## Installation

``` bash
pip install nestor-qt
```

> Past releases have provided executable files, which are still available. 
> New executables are in-development, via beeware's `briefcase` framework.

Requirments: `python>=3.7`. 
Use of virtual environment (pyenv, pipenv, conda, etc.) is recommended.  

With a python installation 

## Who are we?

This toolkit is a part of the Knowledge Extraction and Application for
Smart Manufacturing (KEA) project, within the Systems Integration
Division at NIST.

### Points of Contact

-   [Rachael Sexton](https://www.nist.gov/people/rachael-sexton) Nestor Technical Lead
-   [Michael Brundage](https://www.nist.gov/people/michael-p-brundage)
    Principal Investigator

### Contributors to `nestor-qt`:

Name             |   GitHub Handle
---              |   ---
Rachael Sexton  |   [@rtbs-dev](https://github.com/rtbs-dev)
Sascha Moccozet  |   [@saschaMoccozet](https://github.com/saschaMoccozet)
Michael Brundage |   [@MichaelPBrundage](https://github.com/MichaelPBrundage)
Madhusudanan N.  |   [@msngit](https://github.com/msngit)
Emily Hastings   |   [@emhastings](https://github.com/emhastings)
Lela Bones       |   [@lelatbones](https://github.com/lelatbones)
